Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4414)

Unified Diff: chrome/browser/api/prefs/pref_service_base.h

Issue 10919066: Use BrowserContext as key in API. Switch Autofill to use BC in place of Profile. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Merge to parent Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/api/webdata/web_data_service_base.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/api/prefs/pref_service_base.h
diff --git a/chrome/browser/api/prefs/pref_service_base.h b/chrome/browser/api/prefs/pref_service_base.h
index dbdb051652bea3cf2503b4984c5ba9c73b6425e6..0827c2cc49f4484cb4b00b986c8c74ceb98cf1d0 100644
--- a/chrome/browser/api/prefs/pref_service_base.h
+++ b/chrome/browser/api/prefs/pref_service_base.h
@@ -19,6 +19,7 @@
#include "base/values.h"
namespace content {
+class BrowserContext;
class NotificationObserver;
}
@@ -32,8 +33,8 @@ class TabContents;
class PrefServiceBase {
public:
- // Retrieves a PrefServiceBase for the given profile.
- static PrefServiceBase* ForProfile(Profile* profile);
+ // Retrieves a PrefServiceBase for the given context.
+ static PrefServiceBase* ForContext(content::BrowserContext* context);
virtual ~PrefServiceBase() {}
« no previous file with comments | « no previous file | chrome/browser/api/webdata/web_data_service_base.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698